@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -47,7 +47,7 @@ if TYPE_CHECKING:
 
 
 @no_type_check
-def decrypt(secret, hash, data):  # skipcq: PYL-W0622
+def decrypt(secret, hash, data):
     """
     Decrypt per telegram docs at https://core.telegram.org/passport.
 
@@ -96,7 +96,7 @@ def decrypt(secret, hash, data):  # skipcq: PYL-W0622
 
 
 @no_type_check
-def decrypt_json(secret, hash, data):  # skipcq: PYL-W0622
+def decrypt_json(secret, hash, data):
     """Decrypts data using secret and hash and then decodes utf-8 string and loads json"""
     return json.loads(decrypt(secret, hash, data).decode("utf-8"))
 
@@ -130,17 +130,17 @@ class EncryptedCredentials(TelegramObject):
     """
 
     __slots__ = (
+        "_decrypted_data",
+        "_decrypted_secret",
+        "data",
         "hash",
         "secret",
-        "data",
-        "_decrypted_secret",
-        "_decrypted_data",
     )
 
     def __init__(
         self,
         data: str,
-        hash: str,  # skipcq: PYL-W0622
+        hash: str,
         secret: str,
         *,
         api_kwargs: Optional[JSONDict] = None,
@@ -295,17 +295,17 @@ class SecureData(TelegramObject):
     """
 
     __slots__ = (
-        "utility_bill",
-        "personal_details",
-        "temporary_registration",
         "address",
-        "driver_license",
-        "rental_agreement",
-        "internal_passport",
-        "identity_card",
         "bank_statement",
+        "driver_license",
+        "identity_card",
+        "internal_passport",
         "passport",
         "passport_registration",
+        "personal_details",
+        "rental_agreement",
+        "temporary_registration",
+        "utility_bill",
     )
 
     def __init__(
@@ -424,7 +424,7 @@ class SecureValue(TelegramObject):
 
     """
 
-    __slots__ = ("data", "front_side", "reverse_side", "selfie", "files", "translation")
+    __slots__ = ("data", "files", "front_side", "reverse_side", "selfie", "translation")
 
     def __init__(
         self,
@@ -468,10 +468,14 @@ class SecureValue(TelegramObject):
 class _CredentialsBase(TelegramObject):
     """Base class for DataCredentials and FileCredentials."""
 
-    __slots__ = ("hash", "secret", "file_hash", "data_hash")
+    __slots__ = ("data_hash", "file_hash", "hash", "secret")
 
     def __init__(
-        self, hash: str, secret: str, *, api_kwargs: Optional[JSONDict] = None  # skipcq: PYL-W0622
+        self,
+        hash: str,
+        secret: str,
+        *,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(api_kwargs=api_kwargs)
         with self._unfrozen():
